Learn R Programming

SAEval (version 1.0.0)

sa_shp: Example dataset to map Small Area Estimates

Description

sa_shp contains a sf object to map the small area estimates.

Usage

data(sa_shp)

Arguments

Format

sa_shp is a sf object with the shapefile for the sa domain.

Examples

Run this code
# Load example data
data(sa_shp)

summary(sa_shp)

Run the code above in your browser using DataLab